@@ -128,9 +128,19 @@ ParamSet = R6Class("ParamSet",
     #' @param class (`character()`).
     #' @param is_bounded (`logical(1)`).
     #' @param tags (`character()`).
+    #' @param type (`character(1)`)\cr
+    #' Return values `with_token`, `without_token` or `only_token`?
     #' @return Named `list()`.
-    get_values = function(class = NULL, is_bounded = NULL, tags = NULL) {
+    get_values = function(class = NULL, is_bounded = NULL, tags = NULL, type = "with_token") {
+      assert_choice(type, c("with_token", "without_token", "only_token"))
       values = self$values
+
+      if (type == "without_token") {
+        values = discard(values, is, "TuneToken")
+      } else if (type == "only_token") {
+        values = keep(values, is, "TuneToken")
+      }
+
       values[intersect(names(values), self$ids(class = class, is_bounded = is_bounded, tags = tags))]
     },
 
@@ -157,6 +167,22 @@ ParamSet = R6Class("ParamSet",
       invisible(self)
     },
 
+    #' @description
+    #' Construct a [`ParamSet`] to tune over. Constructed from [`TuneToken`] in `$values`, see [`to_tune()`].
+    #'
+    #' @param  values (`named list`): optional named list of [`TuneToken`] objects to convert, in place of `$values`.
+    search_space = function(values = self$values) {
+      assert_list(values)
+      assert_names(names(values), subset.of = self$ids())
+      pars = private$get_tune_ps(values)
+      on = NULL  # pacify static code check
+      dangling_deps = pars$deps[!on %in% pars$ids()]
+      if (nrow(dangling_deps)) {
+        stopf("Dangling dependencies not allowed: Dependencies on %s dangling", str_collapse(dangling_deps$on))
+      }
+      pars
+    },
+
     #' @description
     #' \pkg{checkmate}-like check-function. Takes a named list.
     #' A point x is feasible, if it configures a subset of params,
@@ -201,8 +227,12 @@ ParamSet = R6Class("ParamSet",
       deps = self$deps
       if (nrow(deps)) {
         for (j in seq_row(deps)) {
+
           p1id = deps$id[j]
           p2id = deps$on[j]
+          if (inherits(xs[[p1id]], "TuneToken") || inherits(xs[[p2id]], "TuneToken")) {
+            next  # be lenient with dependencies when any parameter involved is a TuneToken
+          }
           # we are ONLY ok if:
           # - if param is there, then parent must be there, then cond must be true
           # - if param is not there
@@ -524,8 +554,10 @@ ParamSet = R6Class("ParamSet",
       if (missing(xs)) {
         return(private$.values)
       }
-      if (self$assert_values)
+      if (self$assert_values) {
         self$assert(xs)
+        private$get_tune_ps(xs)  # check that to_tune() are valid
+      }
       if (length(xs) == 0L) {
         xs = named_list()
       } else {
@@ -533,8 +565,8 @@ ParamSet = R6Class("ParamSet",
         # this is not the greatest way to do this, evvery param should maybe have a ".convert"
         # function, but this seems overkill for this single issue
         # solves issue #293
-        int_ids = self$ids(class = "ParamInt")
-        int_ids = intersect(int_ids, names(xs))
+        # (Need to skip over ParamInt that have TuneToken value)
+        int_ids = intersect(self$ids(class = "ParamInt"), names(discard(xs, inherits, "TuneToken")))
         if (length(int_ids) > 0L)
           xs[int_ids] = as.list(as.integer(unlist(xs[int_ids])))
       }
@@ -559,6 +591,37 @@ ParamSet = R6Class("ParamSet",
       params = self$params
       set_names(astype(map(params, member)), names(params))
     },
+    get_tune_ps = function(values) {
+      selfparams = self$params  # cache to avoid performance hit in ParamSetCollection
+      partsets = imap(keep(values, inherits, "TuneToken"), function(value, pn) {
+        tunetoken_to_ps(value, selfparams[[pn]])
+      })
+      idmapping = map(partsets, function(x) x$ids())
+      pars = ps_union(partsets)
+      pars$set_id = self$set_id
+      parsnames = names(pars$params)
+      # only add the dependencies that are also in the tuning PS
+      on = id = NULL  # pacify static code check
+      pmap(self$deps[id %in% names(idmapping) & on %in% names(partsets), c("on", "id", "cond")], function(on, id, cond) {
+        onpar = partsets[[on]]
+        if (onpar$has_trafo || !identical(onpar$ids(), on)) {
+          # cannot have dependency on a parameter that is being trafo'd
+          return(NULL)
+        }
+        # remove infeasible values from condition
+        cond = cond$clone(deep = TRUE)
+        cond$rhs = keep(cond$rhs, pars$params[[on]]$test)
+        if (!length(cond$rhs)) {
+          # no value is feasible, but there may be a trafo that fixes this
+          # so we are forgiving here.
+          return(NULL)
+        }
+        for (idname in idmapping[[id]]) {
+          pars$add_dep(idname, on, cond)
+        }
+      })
+      pars
+    },
 
     deep_clone = function(name, value) {
       switch(name,
